program rechtsbuendigertext;

{$mode objfpc}{$H+}
{$codepage UTF8}


uses
  Sysutils, fppdf, fpttf, pdfhelpers;

var
  FontID, FontBoldID: Integer;
  Document: TPDFDocument;
  Section: TPDFSection;
  Page: TPDFPage;

  procedure WriteAlignedText(Var p : TPDFPage; X,Y : TPDFFloat; aText : String; alignment : TPDFAlign);
  var
    W,H,Desc:TPDFFloat;
  begin
    case alignment of
      alLeft   : P.WriteText(X, Y, aText);
      alRight  : begin
                   P.GetTextDimsMm(aText, W, H,Desc);
                   P.WriteText(X-W, Y, aText);
                 end;
      alCenter : begin
                   P.GetTextDimsMm(aText, W, H,Desc);
                   P.WriteText(X-(W / 2), Y, aText);
                 end;
    end; // case
  end;

begin
  Document := TPDFDocument.Create(nil);
  Document.Infos.Producer := 'Test';
  Document.Infos.CreationDate := Now;
  Document.Options := [poPageOriginAtTop, {poNoEmbeddedFonts,} poSubsetFont, poCompressFonts, poCompressImages];
  Document.DefaultOrientation := ppoPortrait;
  Document.DefaultPaperType := ptA4;
  Document.DefaultUnitOfMeasure := uomMillimeters;
  Document.StartDocument;
  gTTFontCache.ReadStandardFonts;
  FontID := Document.AddSystemFont('Arial', false, false);
  FontBoldID := Document.AddSystemFont('Arial Bold', true, false);

  Section := Document.Sections.AddSection;

  Page := Document.Pages.AddPage;
  Section.AddPage(Page);

  // Überschrift, steht mittig auf der ganzen Seite
  // ausgehend von einer DIN A4 Seitenbreite von 210mm,
  // ist die Seitenmitte bei 105mm
  Page.SetFont(FontID, 11);
  WriteAlignedText(Page,105, 20, 'Demo für WriteAlignedText',alCenter);

  Page.SetFont(FontBoldID, 11);
  // nachfolgende Texte stehen rechtsbündig an der X-Koordinate 104.5
  WriteAlignedText(Page,104.5, 30,'999999999 €',alRight);
  WriteAlignedText(Page,104.5, 36, '88888888 €',alRight);
  WriteAlignedText(Page,104.5, 42, '7777777 €', alRight);
  WriteAlignedText(Page,104.5, 48, '666666 €',alRight);

  // nachfolgende Texte stehen linksbündig an der X-Koordinate 105.5
  WriteAlignedText(Page,105.5, 30,'999999999 €',alLeft);
  WriteAlignedText(Page,105.5, 36, '88888888 €',alLeft);
  WriteAlignedText(Page,105.5, 42, '7777777 €', alLeft);
  WriteAlignedText(Page,105.5, 48, '666666 €', alLeft);

  // nachfolgende Texte stehen zentriert in der SeitenMitte
  WriteAlignedText(Page,105, 60,'999999999',alCenter);
  WriteAlignedText(Page,105, 66, '88888888',alCenter);
  WriteAlignedText(Page,105, 72, '7777777', alCenter);
  WriteAlignedText(Page,105, 78, '666666',alCenter);

  // nachfolgende Texte stehen linksbündig an der X-Koordinate 105.5
  WriteAlignedText(Page,105.5, 90,'999999999 €',alLeft);
  WriteAlignedText(Page,105.5, 96, '88888888 €',alLeft);
  WriteAlignedText(Page,105.5, 102, '7777777 €', alLeft);
  WriteAlignedText(Page,105.5, 108, '666666 €', alLeft);

  // nachfolgende Texte stehen rechtsbündig an der X-Koordinate 104.5
  WriteAlignedText(Page,104.5, 90,'999999999 €',alRight);
  WriteAlignedText(Page,104.5, 96, '88888888 €',alRight);
  WriteAlignedText(Page,104.5, 102, '7777777 €', alRight);
  WriteAlignedText(Page,104.5, 108, '666666 €', alRight);

  Document.SaveToFile('output.pdf');
  Document.free;
end.
